aztec-nr - noir_aztec::note::utils

Function compute_note_hash_for_nullify_from_read_request

pub fn compute_note_hash_for_nullify_from_read_request<Note>(
    retrieved_note: RetrievedNote<Note>,
    note_hash_for_read_request: Field,
) -> Field

Same as compute_note_hash_for_nullify, except it takes the note hash used in a read request (i.e. what compute_note_hash_for_read_request would return). This is useful in scenarios where that hash has already been computed to reduce constraints by reusing this value.