Function compute_note_hash_for_read_request
pub fn compute_note_hash_for_read_request<Note>(
retrieved_note: RetrievedNote<Note>,
storage_slot: Field,
) -> Field
where
Note: NoteHash
pub fn compute_note_hash_for_read_request<Note>(
retrieved_note: RetrievedNote<Note>,
storage_slot: Field,
) -> Field
where
Note: NoteHash
Returns the note hash that must be used to issue a private kernel read request for a note.